"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
exports.__esModule = true;
exports.chatSlotClassNames = exports.chatClassName = exports.Chat = void 0;
var _map2 = _interopRequireDefault(require("lodash/map"));
var _accessibility = require("@fluentui/accessibility");
var _reactBindings = require("@fluentui/react-bindings");
var customPropTypes = _interopRequireWildcard(require("@fluentui/react-proptypes"));
var PropTypes = _interopRequireWildcard(require("prop-types"));
var React = _interopRequireWildcard(require("react"));
var _utils = require("../../utils");
var _chatContext = require("./chatContext");
var _chatDensity = require("./chatDensity");
var _ChatItem = require("./ChatItem");
var _ChatMessage = require("./ChatMessage");
var _ChatMessageDetails = require("./ChatMessageDetails");
var _ChatMessageHeader = require("./ChatMessageHeader");
var _ChatMessageReadStatus = require("./ChatMessageReadStatus");
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function _getRequireWildcardCache(nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
var chatClassName = 'ui-chat';
exports.chatClassName = chatClassName;
var chatSlotClassNames = {
  item: chatClassName + "__item"
};

/**
 * A Chat displays messages from a conversation between multiple users.
 */
exports.chatSlotClassNames = chatSlotClassNames;
var Chat = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var context = (0, _reactBindings.useFluentContext)();
  var _useTelemetry = (0, _reactBindings.useTelemetry)(Chat.displayName, context.telemetry),
    setStart = _useTelemetry.setStart,
    setEnd = _useTelemetry.setEnd;
  setStart();
  var accessibility = props.accessibility,
    children = props.children,
    className = props.className,
    density = props.density,
    design = props.design,
    items = props.items,
    styles = props.styles,
    variables = props.variables;
  var getA11Props = (0, _reactBindings.useAccessibility)(accessibility, {
    debugName: Chat.displayName,
    rtl: context.rtl
  });
  var _useStyles = (0, _reactBindings.useStyles)(Chat.displayName, {
      className: chatClassName,
      mapPropsToStyles: function mapPropsToStyles() {
        return {
          density: density
        };
      },
      mapPropsToInlineStyles: function mapPropsToInlineStyles() {
        return {
          className: className,
          design: design,
          styles: styles,
          variables: variables
        };
      },
      rtl: context.rtl
    }),
    classes = _useStyles.classes;
  var ElementType = (0, _reactBindings.getElementType)(props);
  var unhandledProps = (0, _reactBindings.useUnhandledProps)(Chat.handledProps, props);
  var childBehaviors = accessibility && accessibility(props).childBehaviors;
  var contextProps = {
    density: density,
    behaviors: {
      item: childBehaviors == null ? void 0 : childBehaviors.item,
      message: childBehaviors == null ? void 0 : childBehaviors.message
    }
  };
  var element = getA11Props.unstable_wrapWithFocusZone( /*#__PURE__*/React.createElement(ElementType, getA11Props('root', Object.assign({
    className: classes.root,
    ref: ref
  }, _utils.rtlTextContainer.getAttributes({
    forElements: [children]
  }), unhandledProps)), /*#__PURE__*/React.createElement(_chatContext.ChatContextProvider, {
    value: contextProps
  }, (0, _utils.childrenExist)(children) ? children : (0, _map2.default)(items, function (item) {
    return _ChatItem.ChatItem.create(item, {
      defaultProps: function defaultProps() {
        return {
          className: chatSlotClassNames.item
        };
      }
    });
  }))));
  setEnd();
  return element;
});
exports.Chat = Chat;
Chat.displayName = 'Chat';
Chat.defaultProps = {
  accessibility: _accessibility.chatBehavior,
  as: 'ul',
  density: _chatDensity.defaultChatDensity
};
Chat.propTypes = Object.assign({}, _utils.commonPropTypes.createCommon({
  content: false
}), {
  items: PropTypes.arrayOf(customPropTypes.itemShorthand),
  density: PropTypes.oneOf(['comfy', 'compact'])
});
Chat.handledProps = Object.keys(Chat.propTypes);
Chat.Item = _ChatItem.ChatItem;
Chat.Message = _ChatMessage.ChatMessage;
Chat.MessageHeader = _ChatMessageHeader.ChatMessageHeader;
Chat.MessageDetails = _ChatMessageDetails.ChatMessageDetails;
Chat.MessageReadStatus = _ChatMessageReadStatus.ChatMessageReadStatus;
Chat.create = (0, _utils.createShorthandFactory)({
  Component: Chat
});
//# sourceMappingURL=Chat.js.map
