"use strict";

exports.__esModule = true;
exports.chatItemSlotClassNames = exports.chatItemClassName = exports.ChatItem = void 0;
var _reactBindings = require("@fluentui/react-bindings");
var customPropTypes = _interopRequireWildcard(require("@fluentui/react-proptypes"));
var PropTypes = _interopRequireWildcard(require("prop-types"));
var React = _interopRequireWildcard(require("react"));
var _utils = require("../../utils");
var _Box = require("../Box/Box");
var _chatContext = require("./chatContext");
var _chatItemContext = require("./chatItemContext");
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function _getRequireWildcardCache(nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
var chatItemClassName = 'ui-chat__item';
exports.chatItemClassName = chatItemClassName;
var chatItemSlotClassNames = {
  message: chatItemClassName + "__message",
  gutter: chatItemClassName + "__gutter"
};
exports.chatItemSlotClassNames = chatItemSlotClassNames;
/**
 * A ChatItem is container for single entity in Chat (e.g. message, notification, etc).
 */
var ChatItem = /*#__PURE__*/React.forwardRef(function (inputProps, ref) {
  var context = (0, _reactBindings.useFluentContext)();
  var _useTelemetry = (0, _reactBindings.useTelemetry)(ChatItem.displayName, context.telemetry),
    setStart = _useTelemetry.setStart,
    setEnd = _useTelemetry.setEnd;
  setStart();
  var chatProps = (0, _chatContext.useChatContextSelectors)({
    density: function density(v) {
      return v.density;
    },
    accessibility: function accessibility(v) {
      return v.behaviors.item;
    }
  });
  var props = Object.assign({}, chatProps, inputProps);
  var accessibility = props.accessibility,
    attached = props.attached,
    children = props.children,
    className = props.className,
    contentPosition = props.contentPosition,
    density = props.density,
    design = props.design,
    gutter = props.gutter,
    message = props.message,
    styles = props.styles,
    variables = props.variables,
    _props$unstable_layou = props.unstable_layout,
    layout = _props$unstable_layou === void 0 ? 'default' : _props$unstable_layou;
  var getA11Props = (0, _reactBindings.useAccessibility)(accessibility, {
    debugName: ChatItem.displayName,
    rtl: context.rtl
  });
  var _useStyles = (0, _reactBindings.useStyles)(ChatItem.displayName, {
      className: chatItemClassName,
      mapPropsToStyles: function mapPropsToStyles() {
        return {
          layout: layout,
          attached: attached,
          contentPosition: contentPosition,
          density: density
        };
      },
      mapPropsToInlineStyles: function mapPropsToInlineStyles() {
        return {
          className: className,
          design: design,
          styles: styles,
          variables: variables
        };
      },
      rtl: context.rtl
    }),
    classes = _useStyles.classes,
    resolvedStyles = _useStyles.styles;
  var renderContent = function renderContent() {
    var gutterElement = _Box.Box.create(gutter, {
      defaultProps: function defaultProps() {
        return getA11Props('gutter', {
          className: chatItemSlotClassNames.gutter,
          styles: resolvedStyles.gutter
        });
      }
    });
    var messageElement = _Box.Box.create(message, {
      defaultProps: function defaultProps() {
        return getA11Props('message', {
          className: chatItemSlotClassNames.message,
          styles: resolvedStyles.message
        });
      }
    });
    return /*#__PURE__*/React.createElement(_chatItemContext.ChatItemContextProvider, {
      value: {
        attached: attached
      }
    }, (contentPosition === 'start' || density === 'compact') && gutterElement, messageElement, contentPosition === 'end' && density === 'comfy' && gutterElement);
  };
  var ElementType = (0, _reactBindings.getElementType)(props);
  var unhandledProps = (0, _reactBindings.useUnhandledProps)(ChatItem.handledProps, props);
  var element = /*#__PURE__*/React.createElement(ElementType, getA11Props('root', Object.assign({
    className: classes.root,
    ref: ref
  }, _utils.rtlTextContainer.getAttributes({
    forElements: [children]
  }), unhandledProps)), (0, _utils.childrenExist)(children) ? children : renderContent());
  setEnd();
  return element;
});
exports.ChatItem = ChatItem;
ChatItem.displayName = 'ChatItem';
ChatItem.defaultProps = {
  as: 'li',
  contentPosition: 'start',
  attached: false
};
ChatItem.propTypes = Object.assign({}, _utils.commonPropTypes.createCommon({
  content: false
}), {
  attached: PropTypes.oneOfType([PropTypes.bool, PropTypes.oneOf(['top', 'bottom'])]),
  contentPosition: PropTypes.oneOf(['start', 'end']),
  density: PropTypes.oneOf(['comfy', 'compact']),
  gutter: customPropTypes.itemShorthand,
  message: customPropTypes.itemShorthand,
  unstable_layout: PropTypes.oneOf(['default', 'refresh'])
});
ChatItem.handledProps = Object.keys(ChatItem.propTypes);
ChatItem.create = (0, _utils.createShorthandFactory)({
  Component: ChatItem,
  mappedProp: 'message'
});
//# sourceMappingURL=ChatItem.js.map
