"use strict";

exports.__esModule = true;
exports.menuItemContentClassName = exports.MenuItemContent = void 0;
var React = _interopRequireWildcard(require("react"));
var _reactBindings = require("@fluentui/react-bindings");
var PropTypes = _interopRequireWildcard(require("prop-types"));
var _utils = require("../../utils");
var _menuContext = require("./menuContext");
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function _getRequireWildcardCache(nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
var menuItemContentClassName = 'ui-menu__itemcontent';

/**
 * A MenuItemContent allows a user to have a dedicated component that can be targeted from the theme.
 */
exports.menuItemContentClassName = menuItemContentClassName;
var MenuItemContent = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var context = (0, _reactBindings.useFluentContext)();
  var _useTelemetry = (0, _reactBindings.useTelemetry)(MenuItemContent.displayName, context.telemetry),
    setStart = _useTelemetry.setStart,
    setEnd = _useTelemetry.setEnd;
  setStart();
  var parentProps = (0, _reactBindings.useContextSelectors)(_menuContext.MenuContext, {
    vertical: function vertical(v) {
      return v.vertical;
    }
  }); // TODO: we should improve typings for the useContextSelectors

  var className = props.className,
    children = props.children,
    design = props.design,
    styles = props.styles,
    variables = props.variables,
    content = props.content,
    hasMenu = props.hasMenu,
    hasIcon = props.hasIcon,
    vertical = props.vertical,
    inSubmenu = props.inSubmenu;
  var _useStyles = (0, _reactBindings.useStyles)(MenuItemContent.displayName, {
      className: menuItemContentClassName,
      mapPropsToStyles: function mapPropsToStyles() {
        return {
          hasMenu: hasMenu,
          hasIcon: hasIcon,
          vertical: vertical || parentProps.vertical,
          inSubmenu: inSubmenu
        };
      },
      mapPropsToInlineStyles: function mapPropsToInlineStyles() {
        return {
          className: className,
          design: design,
          styles: styles,
          variables: variables
        };
      },
      rtl: context.rtl
    }),
    classes = _useStyles.classes;
  var getA11Props = (0, _reactBindings.useAccessibility)(props.accessibility, {
    debugName: MenuItemContent.displayName,
    rtl: context.rtl
  });
  var ElementType = (0, _reactBindings.getElementType)(props);
  var unhandledProps = (0, _reactBindings.useUnhandledProps)(MenuItemContent.handledProps, props);
  var element = /*#__PURE__*/React.createElement(ElementType, getA11Props('root', Object.assign({
    className: classes.root
  }, _utils.rtlTextContainer.getAttributes({
    forElements: [children, content]
  }), {
    ref: ref
  }, unhandledProps)), (0, _reactBindings.childrenExist)(children) ? children : content);
  setEnd();
  return element;
});
exports.MenuItemContent = MenuItemContent;
MenuItemContent.displayName = 'MenuItemContent';
MenuItemContent.defaultProps = {
  as: 'span'
};
MenuItemContent.propTypes = Object.assign({}, _utils.commonPropTypes.createCommon(), {
  hasIcon: PropTypes.bool,
  hasMenu: PropTypes.bool,
  vertical: PropTypes.bool,
  inSubmenu: PropTypes.bool
});
MenuItemContent.shorthandConfig = {
  mappedProp: 'content'
};
MenuItemContent.handledProps = Object.keys(MenuItemContent.propTypes);
//# sourceMappingURL=MenuItemContent.js.map
