"use strict";

exports.__esModule = true;
exports.segmentClassName = exports.Segment = void 0;
var React = _interopRequireWildcard(require("react"));
var PropTypes = _interopRequireWildcard(require("prop-types"));
var _utils = require("../../utils");
var _Box = require("../Box/Box");
var _reactBindings = require("@fluentui/react-bindings");
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function _getRequireWildcardCache(nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
var segmentClassName = 'ui-segment';

/**
 * A Segment visually groups related content.
 */
exports.segmentClassName = segmentClassName;
var Segment = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var context = (0, _reactBindings.useFluentContext)();
  var _useTelemetry = (0, _reactBindings.useTelemetry)(Segment.displayName, context.telemetry),
    setStart = _useTelemetry.setStart,
    setEnd = _useTelemetry.setEnd;
  setStart();
  var children = props.children,
    content = props.content,
    color = props.color,
    inverted = props.inverted,
    disabled = props.disabled,
    className = props.className,
    design = props.design,
    styles = props.styles,
    variables = props.variables;
  var ElementType = (0, _reactBindings.getElementType)(props);
  var unhandledProps = (0, _reactBindings.useUnhandledProps)(Segment.handledProps, props);
  var getA11yProps = (0, _reactBindings.useAccessibility)(props.accessibility, {
    debugName: Segment.displayName,
    rtl: context.rtl
  });
  var _useStyles = (0, _reactBindings.useStyles)(Segment.displayName, {
      className: segmentClassName,
      mapPropsToStyles: function mapPropsToStyles() {
        return {
          color: color,
          inverted: inverted,
          disabled: disabled
        };
      },
      mapPropsToInlineStyles: function mapPropsToInlineStyles() {
        return {
          className: className,
          design: design,
          styles: styles,
          variables: variables
        };
      },
      rtl: context.rtl
    }),
    classes = _useStyles.classes;
  var element = getA11yProps.unstable_wrapWithFocusZone( /*#__PURE__*/React.createElement(ElementType, getA11yProps('root', Object.assign({
    className: classes.root,
    ref: ref
  }, _utils.rtlTextContainer.getAttributes({
    forElements: [children]
  }), unhandledProps)), (0, _utils.childrenExist)(children) ? children : _Box.Box.create(content)));
  setEnd();
  return element;
});
exports.Segment = Segment;
Segment.displayName = 'Segment';
Segment.propTypes = Object.assign({}, _utils.commonPropTypes.createCommon({
  content: 'shorthand',
  color: true
}), {
  disabled: PropTypes.bool,
  inverted: PropTypes.bool
});
Segment.handledProps = Object.keys(Segment.propTypes);
Segment.create = (0, _utils.createShorthandFactory)({
  Component: Segment
});
//# sourceMappingURL=Segment.js.map
