"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
exports.__esModule = true;
exports.tableRowClassName = exports.TableRow = void 0;
var _map2 = _interopRequireDefault(require("lodash/map"));
var _invoke2 = _interopRequireDefault(require("lodash/invoke"));
var _accessibility = require("@fluentui/accessibility");
var _reactBindings = require("@fluentui/react-bindings");
var _reactComponentRef = require("@fluentui/react-component-ref");
var customPropTypes = _interopRequireWildcard(require("@fluentui/react-proptypes"));
var PropTypes = _interopRequireWildcard(require("prop-types"));
var React = _interopRequireWildcard(require("react"));
var _utils = require("../../utils");
var _TableCell = require("./TableCell");
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function _getRequireWildcardCache(nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
var tableRowClassName = 'ui-table__row';
exports.tableRowClassName = tableRowClassName;
/**
 * Component represents a single row in a tabular structure
 */
var TableRow = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var context = (0, _reactBindings.useFluentContext)();
  var _useTelemetry = (0, _reactBindings.useTelemetry)(TableRow.displayName, context.telemetry),
    setStart = _useTelemetry.setStart,
    setEnd = _useTelemetry.setEnd;
  setStart();
  var rowRef = React.useRef();
  var className = props.className,
    design = props.design,
    styles = props.styles,
    items = props.items,
    header = props.header,
    compact = props.compact,
    children = props.children,
    accessibility = props.accessibility,
    variables = props.variables,
    selected = props.selected;
  var hasChildren = (0, _utils.childrenExist)(children);
  var ElementType = (0, _reactBindings.getElementType)(props);
  var unhandledProps = (0, _reactBindings.useUnhandledProps)(TableRow.handledProps, props);
  var getA11yProps = (0, _reactBindings.useAccessibility)(accessibility, {
    debugName: TableRow.displayName,
    actionHandlers: {
      // https://github.com/microsoft/fluent-ui-react/issues/2150
      unsetRowTabbable: function unsetRowTabbable(e) {
        rowRef.current.setAttribute('tabindex', '-1');
      },
      performClick: function performClick(e) {
        if (e.currentTarget === e.target) {
          (0, _invoke2.default)(props, 'onClick', e, props);
          e.preventDefault();
        }
      }
    },
    mapPropsToBehavior: function mapPropsToBehavior() {
      return {
        selected: selected,
        header: header
      };
    },
    rtl: context.rtl
  });
  var _useStyles = (0, _reactBindings.useStyles)(TableRow.displayName, {
      className: tableRowClassName,
      mapPropsToStyles: function mapPropsToStyles() {
        return {
          header: header,
          compact: compact
        };
      },
      mapPropsToInlineStyles: function mapPropsToInlineStyles() {
        return {
          className: className,
          design: design,
          styles: styles,
          variables: variables
        };
      },
      rtl: context.rtl
    }),
    classes = _useStyles.classes;
  var renderCells = function renderCells() {
    return (0, _map2.default)(items, function (item) {
      return _TableCell.TableCell.create(item, {
        defaultProps: function defaultProps() {
          return getA11yProps('cell', {});
        },
        overrideProps: function overrideProps(predefinedProps) {
          return {
            variables: (0, _reactBindings.mergeVariablesOverrides)(variables, predefinedProps.variables)
          };
        }
      });
    });
  };
  var element = /*#__PURE__*/React.createElement(_reactComponentRef.Ref, {
    innerRef: rowRef
  }, getA11yProps.unstable_wrapWithFocusZone( /*#__PURE__*/React.createElement(ElementType, getA11yProps('root', Object.assign({
    className: classes.root,
    ref: ref
  }, unhandledProps)), hasChildren && children, !hasChildren && renderCells())));
  setEnd();
  return element;
});
exports.TableRow = TableRow;
TableRow.displayName = 'TableRow';
TableRow.propTypes = Object.assign({}, _utils.commonPropTypes.createCommon({
  content: false
}), {
  items: customPropTypes.collectionShorthand,
  header: PropTypes.bool,
  compact: PropTypes.bool,
  selected: PropTypes.bool
});
TableRow.handledProps = Object.keys(TableRow.propTypes);
TableRow.defaultProps = {
  accessibility: _accessibility.tableRowBehavior
};
TableRow.create = (0, _utils.createShorthandFactory)({
  Component: TableRow,
  mappedArrayProp: 'items'
});
//# sourceMappingURL=TableRow.js.map
