"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
exports.__esModule = true;
exports.textAreaClassName = exports.TextArea = void 0;
var _invoke2 = _interopRequireDefault(require("lodash/invoke"));
var _get2 = _interopRequireDefault(require("lodash/get"));
var _accessibility = require("@fluentui/accessibility");
var React = _interopRequireWildcard(require("react"));
var PropTypes = _interopRequireWildcard(require("prop-types"));
var _utils = require("../../utils");
var _reactBindings = require("@fluentui/react-bindings");
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function _getRequireWildcardCache(nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
var textAreaClassName = 'ui-textarea';

/**
 * A TextArea is a multi-line plan-text editing control.
 *
 * @accessibility
 * For good screen reader experience set `aria-label` or `aria-labelledby` attribute for textarea.
 * When using maxlength attribute, provide the information about max length in label for screen reader.
 * @accessibilityIssues
 * [NVDA - No announcement of maxlength](https://github.com/nvaccess/nvda/issues/7910)
 * [JAWS - textarea - no announcement of maxlength](https://github.com/FreedomScientific/VFO-standards-support/issues/300)
 */
exports.textAreaClassName = textAreaClassName;
var TextArea = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var context = (0, _reactBindings.useFluentContext)();
  var _useTelemetry = (0, _reactBindings.useTelemetry)(TextArea.displayName, context.telemetry),
    setStart = _useTelemetry.setStart,
    setEnd = _useTelemetry.setEnd;
  setStart();
  var disabled = props.disabled,
    accessibility = props.accessibility,
    inverted = props.inverted,
    resize = props.resize,
    fluid = props.fluid,
    className = props.className,
    design = props.design,
    styles = props.styles,
    variables = props.variables,
    error = props.error;
  var _useAutoControlled = (0, _reactBindings.useAutoControlled)({
      defaultValue: props.defaultValue,
      value: props.value,
      initialValue: ''
    }),
    value = _useAutoControlled[0],
    setValue = _useAutoControlled[1];
  var unhandledProps = (0, _reactBindings.useUnhandledProps)(TextArea.handledProps, props);
  var getA11yProps = (0, _reactBindings.useAccessibility)(accessibility, {
    debugName: TextArea.displayName,
    mapPropsToBehavior: function mapPropsToBehavior() {
      return {
        disabled: disabled
      };
    },
    rtl: context.rtl
  });
  var _useStyles = (0, _reactBindings.useStyles)(TextArea.displayName, {
      className: textAreaClassName,
      mapPropsToStyles: function mapPropsToStyles() {
        return {
          inverted: inverted,
          resize: resize,
          fluid: fluid,
          disabled: disabled,
          error: error
        };
      },
      mapPropsToInlineStyles: function mapPropsToInlineStyles() {
        return {
          className: className,
          design: design,
          styles: styles,
          variables: variables
        };
      },
      rtl: context.rtl
    }),
    classes = _useStyles.classes;
  var ElementType = (0, _reactBindings.getElementType)(props);
  var handleChange = function handleChange(e) {
    var newValue = (0, _get2.default)(e, 'target.value');
    (0, _invoke2.default)(props, 'onChange', e, Object.assign({}, props, {
      value: newValue
    }));
    setValue(newValue);
  };
  var element = /*#__PURE__*/React.createElement(ElementType, getA11yProps('root', Object.assign({
    className: classes.root,
    value: value,
    disabled: disabled,
    ref: ref,
    onChange: handleChange
  }, unhandledProps)));
  setEnd();
  return element;
});
exports.TextArea = TextArea;
TextArea.displayName = 'TextArea';
TextArea.propTypes = Object.assign({}, _utils.commonPropTypes.createCommon({
  content: false
}), {
  defaultValue: PropTypes.string,
  onChange: PropTypes.func,
  value: PropTypes.string,
  disabled: PropTypes.bool,
  inverted: PropTypes.bool,
  fluid: PropTypes.bool,
  error: PropTypes.bool,
  resize: PropTypes.oneOf(['none', 'both', 'horizontal', 'vertical'])
});
TextArea.defaultProps = {
  as: 'textarea',
  accessibility: _accessibility.textAreaBehavior
};
TextArea.handledProps = Object.keys(TextArea.propTypes);
TextArea.create = (0, _utils.createShorthandFactory)({
  Component: TextArea
});
//# sourceMappingURL=TextArea.js.map
