"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
exports.__esModule = true;
exports.toolbarCustomItemClassName = exports.ToolbarCustomItem = void 0;
var _invoke2 = _interopRequireDefault(require("lodash/invoke"));
var _accessibility = require("@fluentui/accessibility");
var _reactBindings = require("@fluentui/react-bindings");
var PropTypes = _interopRequireWildcard(require("prop-types"));
var React = _interopRequireWildcard(require("react"));
var _utils = require("../../utils");
var _toolbarVariablesContext = require("./toolbarVariablesContext");
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function _getRequireWildcardCache(nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
var toolbarCustomItemClassName = 'ui-toolbar__customitem';

/**
 * A ToolbarCustomItem renders Toolbar item as a non-actionable `div` with custom content inside.
 */
exports.toolbarCustomItemClassName = toolbarCustomItemClassName;
var ToolbarCustomItem = (0, _reactBindings.compose)(function (props, ref, composeOptions) {
  var _Object$assign;
  var context = (0, _reactBindings.useFluentContext)();
  var _useTelemetry = (0, _reactBindings.useTelemetry)(composeOptions.displayName, context.telemetry),
    setStart = _useTelemetry.setStart,
    setEnd = _useTelemetry.setEnd;
  setStart();
  var accessibility = props.accessibility,
    children = props.children,
    className = props.className,
    content = props.content,
    design = props.design,
    fitted = props.fitted,
    focusable = props.focusable,
    styles = props.styles,
    variables = props.variables;
  var parentVariables = React.useContext(_toolbarVariablesContext.ToolbarVariablesContext);
  var getA11yProps = (0, _reactBindings.useAccessibility)(accessibility, {
    debugName: composeOptions.displayName,
    rtl: context.rtl
  });
  var _useStyles = (0, _reactBindings.useStyles)(composeOptions.displayName, {
      className: composeOptions.className,
      composeOptions: composeOptions,
      mapPropsToStyles: function mapPropsToStyles() {
        return {
          fitted: fitted
        };
      },
      mapPropsToInlineStyles: function mapPropsToInlineStyles() {
        return {
          className: className,
          design: design,
          styles: styles,
          variables: (0, _reactBindings.mergeVariablesOverrides)(parentVariables, variables)
        };
      },
      rtl: context.rtl,
      unstable_props: props
    }),
    classes = _useStyles.classes;
  var ElementType = (0, _reactBindings.getElementType)(props);
  var unhandledProps = (0, _reactBindings.useUnhandledProps)(composeOptions.handledProps, props);
  var handleBlur = function handleBlur(e) {
    if (focusable) {
      (0, _invoke2.default)(props, 'onBlur', e, props);
    }
  };
  var handleFocus = function handleFocus(e) {
    if (focusable) {
      (0, _invoke2.default)(props, 'onFocus', e, props);
    }
  };
  var element = /*#__PURE__*/React.createElement(ElementType, getA11yProps('root', Object.assign((_Object$assign = {}, _Object$assign[_accessibility.IS_FOCUSABLE_ATTRIBUTE] = focusable, _Object$assign), unhandledProps, {
    className: classes.root,
    onBlur: handleBlur,
    onFocus: handleFocus,
    ref: ref
  })), (0, _utils.childrenExist)(children) ? children : content);
  setEnd();
  return element;
}, {
  className: toolbarCustomItemClassName,
  displayName: 'ToolbarCustomItem',
  shorthandConfig: {
    mappedProp: 'content'
  },
  handledProps: ['accessibility', 'as', 'children', 'className', 'content', 'design', 'fitted', 'focusable', 'onBlur', 'onFocus', 'styles', 'variables']
});
exports.ToolbarCustomItem = ToolbarCustomItem;
ToolbarCustomItem.propTypes = Object.assign({}, _utils.commonPropTypes.createCommon(), {
  fitted: PropTypes.oneOfType([PropTypes.bool, PropTypes.oneOf(['horizontally', 'vertically'])]),
  focusable: PropTypes.bool,
  onFocus: PropTypes.func,
  onBlur: PropTypes.func
});
//# sourceMappingURL=ToolbarCustomItem.js.map
