import { Accessibility, ToolbarMenuBehaviorProps } from '@fluentui/accessibility';
import { UIComponentProps, ChildrenComponentProps, ContentComponentProps } from '../../utils';
import { ComponentEventHandler, ShorthandCollection, ShorthandValue } from '../../types';
import { ToolbarMenuItemProps } from './ToolbarMenuItem';
import { BoxProps } from '../Box/Box';
import { ToolbarDividerProps } from './ToolbarDivider';
import { ToolbarItemProps } from './ToolbarItem';
export declare type ToolbarMenuItemShorthandKinds = {
    divider: ToolbarDividerProps;
    item: ToolbarItemProps;
    toggle: ToolbarItemProps;
};
export interface ToolbarMenuProps extends UIComponentProps, ChildrenComponentProps, ContentComponentProps {
    /**
     * Accessibility behavior if overridden by the user.
     */
    accessibility?: Accessibility<ToolbarMenuBehaviorProps>;
    /** Shorthand array of props for ToolbarMenu. */
    items?: ShorthandCollection<ToolbarMenuItemProps, ToolbarMenuItemShorthandKinds>;
    /**
     * Called on item click.
     *
     * @param event - React's original SyntheticEvent.
     * @param data - All item props.
     */
    onItemClick?: ComponentEventHandler<ToolbarMenuItemProps>;
    /** Indicates whether the menu is submenu. */
    submenu?: boolean;
    /** Shorthand for the submenu indicator. */
    submenuIndicator?: ShorthandValue<BoxProps>;
}
export declare type ToolbarMenuStylesProps = never;
export declare const toolbarMenuClassName = "ui-toolbar__menu";
/**
 * A ToolbarMenu creates a pop-up menu attached to a ToolbarItem.
 *
 * @accessibility
 * Implements pop-up menu (submenu) behavior of [ARIA Menu](https://www.w3.org/TR/wai-aria-practices-1.1/#menu) design pattern.
 */
export declare const ToolbarMenu: import("@fluentui/react-bindings").ComponentWithAs<"ul", ToolbarMenuProps>;
