import { IsConformantOptions } from '@fluentui/react-conformance';
import * as React from 'react';
import { ComponentType } from 'enzyme';
interface Conformant<TProps = {}> extends Pick<IsConformantOptions<TProps>, 'disabledTests' | 'testOptions' | 'getTargetElement'> {
    /** Path to the test file. */
    testPath: string;
    constructorName?: string;
    /** Map of events and the child component to target. */
    eventTargets?: object;
    hasAccessibilityProp?: boolean;
    /** Props required to render Component without errors or warnings. */
    requiredProps?: object;
    /** This component uses wrapper slot to wrap the 'meaningful' element. */
    wrapperComponent?: React.ElementType;
    /** Helpers such as FocusZone and Ref which should be ignored when finding nontrivial children. */
    helperComponents?: React.ElementType[];
    /** List of autocontrolled props for this component. */
    autoControlledProps?: string[];
    /** Child component that will receive unhandledProps. */
    targetComponent?: ComponentType<any>;
    /** Child component that will receive ref. */
    forwardsRefTo?: string | false;
    /**
     * Whether to skip tests for the `as` prop. If `all` skip all the tests.
     * If `as-component` skip the tests for rendering as a class or function component.
     */
    skipAsPropTests?: 'all' | 'as-component';
}
/**
 * Assert Component conforms to guidelines that are applicable to all components.
 * @param Component - A component that should conform.
 */
export declare function isConformant(Component: React.ComponentType<any> & {
    handledProps?: string[];
    autoControlledProps?: string[];
    deprecated_className?: string;
}, options: Conformant): void;
export {};
