import { Accessibility, DatepickerCalendarCellButtonBehaviorProps } from '@fluentui/accessibility';
import { ComponentEventHandler, ComponentKeyboardEventHandler } from '../../types';
import { ContentComponentProps, UIComponentProps } from '../../utils';
export interface DatepickerCalendarCellButtonProps extends UIComponentProps, ContentComponentProps {
    /**
     * Accessibility behavior if overridden by the user.
     */
    accessibility?: Accessibility<DatepickerCalendarCellButtonBehaviorProps>;
    /**
     * Called on click.
     *
     * @param event - React's original SyntheticEvent.
     * @param data - All props.
     */
    onClick?: ComponentEventHandler<DatepickerCalendarCellButtonProps>;
    /**
     * Called on focus.
     *
     * @param event - React's original SyntheticEvent.
     * @param data - All props.
     */
    onFocus?: ComponentEventHandler<DatepickerCalendarCellButtonProps>;
    /** A cell can show that it cannot be interacted with. */
    disabled?: boolean;
    /** A cell can show that it is currently selected or not. */
    selected?: boolean;
    /** Denotes that the cell marks today's date. */
    today?: boolean;
    /** A cell can show that it currently has dimmed styles. */
    quiet?: boolean;
    /**
     * Called on selected item key down.
     *
     * @param event - React's original SyntheticEvent.
     * @param data - All props and proposed value.
     */
    onKeyDown?: ComponentKeyboardEventHandler<DatepickerCalendarCellButtonProps>;
}
export declare type DatepickerCalendarCellButtonStylesProps = Pick<DatepickerCalendarCellButtonProps, 'disabled' | 'selected' | 'quiet' | 'today'>;
export declare const datepickerCalendarCellButtonClassName = "ui-datepicker__calendarcellbutton";
/**
 * A Datepicker cell is used to display calendar grid cell button.
 */
export declare const DatepickerCalendarCellButton: import("@fluentui/react-bindings").ComponentWithAs<"button", DatepickerCalendarCellButtonProps>;
