import * as React from 'react';
import { Accessibility, IndicatorBehaviorProps } from '@fluentui/accessibility';
import * as PropTypes from 'prop-types';
import { ChildrenComponentProps, ContentComponentProps, UIComponentProps } from '../../utils';
import { FluentComponentStaticProps } from '../../types';
export interface MenuItemIndicatorProps extends UIComponentProps, ContentComponentProps, ChildrenComponentProps {
    /** Accessibility behavior if overridden by the user. */
    accessibility?: Accessibility<IndicatorBehaviorProps>;
    /** Indicates if the parent menu item may have just icons. */
    iconOnly?: boolean;
    /** Indicates whether the parent menu item is inside vertical menu. */
    vertical?: boolean;
    /** Indicates whether the parent menu item is part of submenu. */
    inSubmenu?: boolean;
    /** Indicates whether the parent menu item is active. */
    active?: boolean;
    /** Indicates whether the parent menu item is primary. */
    primary?: boolean;
    /** Indicates whether the parent menu item is underlined. */
    underlined?: boolean;
}
export declare type MenuItemIndicatorStylesProps = Pick<MenuItemIndicatorProps, 'iconOnly' | 'vertical' | 'inSubmenu' | 'active' | 'primary' | 'underlined'>;
export declare const menuItemIndicatorClassName = "ui-menu__itemindicator";
/**
 * A MenuItemIndicator allows a user to have a dedicated component that can be targeted from the theme.
 */
export declare const MenuItemIndicator: (<TExtendedElementType extends React.ElementType<any> = "span">(props: React.RefAttributes<HTMLSpanElement> & Omit<import("@fluentui/react-bindings").PropsOfElement<TExtendedElementType>, "as" | keyof MenuItemIndicatorProps> & {
    as?: TExtendedElementType;
} & MenuItemIndicatorProps) => JSX.Element) & {
    propTypes?: React.WeakValidationMap<MenuItemIndicatorProps> & {
        as: React.Requireable<string | ((props: any, context?: any) => any) | (new (props: any, context?: any) => any)>;
    };
    contextTypes?: PropTypes.ValidationMap<any>;
    defaultProps?: Partial<MenuItemIndicatorProps & {
        as: "span";
    }>;
    displayName?: string;
    readonly __PRIVATE_PROPS?: React.RefAttributes<HTMLSpanElement> & Omit<Pick<React.DetailedHTMLProps<React.HTMLAttributes<HTMLSpanElement>, HTMLSpanElement>, "key" | keyof React.HTMLAttributes<HTMLSpanElement>> & {
        ref?: React.Ref<HTMLSpanElement>;
    }, "as" | keyof MenuItemIndicatorProps> & {
        as?: "span";
    } & MenuItemIndicatorProps;
} & FluentComponentStaticProps<MenuItemIndicatorProps>;
