import { toolbarMenuDividerBehavior } from '@fluentui/accessibility';
import { getElementType, mergeVariablesOverrides, useUnhandledProps, useAccessibility, useStyles, useFluentContext, useTelemetry, compose } from '@fluentui/react-bindings';
import * as React from 'react';
import { commonPropTypes } from '../../utils';
import { ToolbarVariablesContext } from './toolbarVariablesContext';
export var toolbarMenuDividerClassName = 'ui-toolbar__menudivider';

/**
 * A ToolbarMenuDivider adds non-actionable separator between items of ToolbarMenu.
 */
export var ToolbarMenuDivider = /*#__PURE__*/function () {
  var ToolbarMenuDivider = compose(function (props, ref, composeOptions) {
    var context = useFluentContext();
    var _useTelemetry = useTelemetry(composeOptions.displayName, context.telemetry),
      setStart = _useTelemetry.setStart,
      setEnd = _useTelemetry.setEnd;
    setStart();
    var accessibility = props.accessibility,
      className = props.className,
      design = props.design,
      styles = props.styles,
      variables = props.variables;
    var parentVariables = React.useContext(ToolbarVariablesContext);
    var getA11yProps = useAccessibility(accessibility, {
      debugName: composeOptions.displayName,
      rtl: context.rtl
    });
    var _useStyles = useStyles(composeOptions.displayName, {
        className: composeOptions.className,
        composeOptions: composeOptions,
        mapPropsToInlineStyles: function mapPropsToInlineStyles() {
          return {
            className: className,
            design: design,
            styles: styles,
            variables: mergeVariablesOverrides(parentVariables, variables)
          };
        },
        rtl: context.rtl,
        unstable_props: props
      }),
      classes = _useStyles.classes;
    var ElementType = getElementType(props);
    var unhandledProps = useUnhandledProps(composeOptions.handledProps, props);
    var element = /*#__PURE__*/React.createElement(ElementType, getA11yProps('root', Object.assign({}, unhandledProps, {
      className: classes.root,
      ref: ref
    })));
    setEnd();
    return element;
  }, {
    className: toolbarMenuDividerClassName,
    displayName: 'ToolbarMenuDivider',
    shorthandConfig: {
      mappedProp: 'content'
    },
    handledProps: ['accessibility', 'as', 'children', 'className', 'content', 'design', 'styles', 'variables']
  });
  ToolbarMenuDivider.propTypes = commonPropTypes.createCommon();
  ToolbarMenuDivider.defaultProps = {
    as: 'li',
    accessibility: toolbarMenuDividerBehavior
  };
  return ToolbarMenuDivider;
}();
//# sourceMappingURL=ToolbarMenuDivider.js.map
