import { Accessibility, ToolbarRadioGroupBehaviorProps } from '@fluentui/accessibility';
import { ChildrenComponentProps, ContentComponentProps, UIComponentProps } from '../../utils';
import { ShorthandCollection } from '../../types';
import { ToolbarDividerProps } from './ToolbarDivider';
import { ToolbarItemProps } from './ToolbarItem';
export declare type ToolbarRadioGroupItemShorthandKinds = {
    divider: ToolbarDividerProps;
    item: ToolbarItemProps;
};
export interface ToolbarRadioGroupProps extends UIComponentProps, ChildrenComponentProps, ContentComponentProps {
    /**
     * Accessibility behavior if overridden by the user.
     */
    accessibility?: Accessibility<ToolbarRadioGroupBehaviorProps>;
    /** Index of the currently active item. */
    activeIndex?: number;
    /** Shorthand array of props for ToolbarRadioGroup. */
    items?: ShorthandCollection<ToolbarItemProps, ToolbarRadioGroupItemShorthandKinds>;
}
export declare type ToolbarRadioGroupStylesProps = never;
export declare const toolbarRadioGroupClassName = "ui-toolbars";
/**
 * A ToolbarRadioGroup renders Toolbar item as a group of mutually exclusive options.
 * Component doesn't implement mutual exclusiveness, it just serves accessibility purposes.
 *
 * @accessibility
 * Implements [ARIA RadioGroup](https://www.w3.org/TR/wai-aria-practices/#radiobutton) design pattern.
 */
export declare const ToolbarRadioGroup: import("@fluentui/react-bindings").ComponentWithAs<"div", ToolbarRadioGroupProps>;
